
# python modules used
import os
import string

# local modules used
import opusutil
import base_db
import missionquery

class HST_Mission_db(missionquery.Mission_db):
  """
=======================================================================
Class: HST_Mission_db 

Description:
------------
This class provides access to the HST-specific relations in the 
mission (OPUS) database.
It inherits common function from the missionquery.Mission_db class.

Methods:
--------

History:
--------
10/01/02 xxxxx MSwam     Initial version
07/15/10 57271 MSwam     remove db retry parameter

=======================================================================
  """
  def __init__(self, server, dbname):
    #
    # call Superclass constructor
    missionquery.Mission_db.__init__(self, server, dbname)

  """
=======================================================================
Name: dads_archive_response

Description:
------------
This function queries the dads_archive table for a given dataset_name
and returns the value of the response field, if a record was found.

Returns:
--------
response - value of dads_archive.response for a given dataset_name or blank

=======================================================================
  """
  def dads_archive_response(self, dataset):
    #
    # build the query template
    querytxt = ("SELECT DISTINCT response FROM dads_archive "+
                "WHERE dataset_name = '"+string.upper(dataset)+"'")
    #
    # get results in a list of lists
    result = [[]]
    self.zombie_select(querytxt, result)
    #
    # if no result found, return blank
    if len(result) == 0:
      return " "
    #
    opusutil.PrintMsg("D","response="+str(result))
    return result[0][0]

  """
=======================================================================
Name: asn_products

Description:
------------
This function queries the asn_members table for a given ASN rootname 
and returns the pppssooo of the products. 
Serious error if no records are found.

Returns:
--------
products - value of asn_members for a given ASN rootname 

History:
--------
06/03/10 64909 Sherbert   needed for updating QUAL* keywords 

=======================================================================
  """
  def asn_products(self, dataset):
    nm = 'asn_products'
    #
    # build the query template
    querytxt  = "SELECT SUBSTRING('"+dataset+"',1,1)+" 
    querytxt += "program_id+obset_id+member_num "
    querytxt += "FROM asn_members "
    querytxt += "WHERE association_id = '"+ string.upper(dataset) 
    querytxt += "' AND member_type LIKE 'PROD%'"
    #
    # get results in a list of lists
    results = [[]]
    self.zombie_select(querytxt, results)
    #
    # if no result found, return blank
    if len(results) == 0:
      return " "
    #
    opusutil.PrintMsg( 'D', 'response='+str(results), nm )
    # Turn list of lists into a single list
    result = []
    for item in results :
        for subitem in item :
            result.append( subitem )
    return result

#========================================================================
# TEST 
# % python hst_missionquery.py
#========================================================================
if __name__ == "__main__":
  # connect to OPUS db
  opus_db = HST_Mission_db(os.environ['OPUS_SERVER'], 
                           'opus_ops')

  # call base class function
  opusutil.PrintMsg("I","archive_class_map="+
                    str(opus_db.get_archive_class_map()))

  # test dads_archive_response
  root = 'ib3w38020'
  msg = 'dads_archive_response for ' +root+ ' is '+ str(opus_db.dads_archive_response(root))
  # test asn_products
  root = 'IB3W01010'
  results = opus_db.asn_products(root) 
  msg = 'asn_products for ' +root+ ' are ' + str(results)
  opusutil.PrintMsg( 'I', msg )
  
  #
  opus_db.close()
